@@ -47,7 +47,7 @@ from contextlib import contextmanager
 import msgpack
 import pylibmc
 
-VERSION = "0.8.2"
+VERSION = "0.8.4"
 RUN_PATH = "/run/starrydb/"
 SERVER_ADDRESS = f"{RUN_PATH}address"
 CACHE_SOCKET = f"{RUN_PATH}cache.sock"
@@ -1096,14 +1096,15 @@ class StarryDepot(object):
 
 class StarryClient(object):
     class Connection(object):
-        def __init__(self, conn):
+        def __init__(self, conn, timeout):
             self.conn = conn
+            self.timeout = timeout
 
         def _callableForward(self, func, *args):
             try:
                 self.conn.send((func, *args))
 
-                if self.conn.poll(30):
+                if self.conn.poll(self.timeout):
                     return self.conn.recv()
                 else:
                     return (False, "timeout.")
@@ -1170,11 +1171,24 @@ class StarryClient(object):
         def deleteMulti(self, keys):
             return self._callableForward("deleteMulti", keys)
 
-    def __init__(self, address=SERVER_ADDRESS, workers=1, authkey=b'starry'):
+    def __init__(self, address=SERVER_ADDRESS, path=None, workers=1, authkey=b'starry', timeout=30):
         self.workers = queue.SimpleQueue()
+        self.address = address
+        self.authkey = authkey
+        self.queue_timeout = int(timeout/3) if timeout > 3 else 1
+        self.conn_timeout = self.queue_timeout * 2
+        self.path = None
+
+        if path is not None:
+            self.path = os.path.abspath(path)
 
         for _ in range(int(workers)):
-            self.workers.put(multiprocessing.connection.Client(address, authkey=authkey))
+            client = multiprocessing.connection.Client(self.address, authkey=self.authkey)
+
+            if self.path is not None:
+                client.send(("open", self.path))
+
+            self.workers.put(client)
 
     def __del__(self):
         try:
@@ -1195,34 +1209,45 @@ class StarryClient(object):
         self.__del__()
 
     @contextmanager
-    def open(self, path, timeout=30):
+    def open(self, path=None):
+        thread_flag = False
+
         try:
-            client = self.workers.get(timeout=timeout)
+            client = self.workers.get(timeout=self.queue_timeout)
         except queue.Empty:
-            raise StarryError("no client is available.")
+            if path is None and self.path is None:
+                raise StarryError("no path.")
+
+            try:
+                client = multiprocessing.connection.Client(self.address, authkey=self.authkey)
+            except Exception as e:
+                raise StarryError(f"Caught exception: {e.__doc__}({e})")
+
+            thread_flag = True
         except Exception as e:
             raise StarryError(f"Caught exception: {e.__doc__}({e})")
 
         try:
-            path = os.path.abspath(path)
-            client.send(("open", path))
+            if path is not None:
+                client.send(("open", os.path.abspath(path)))
+            elif thread_flag is True:
+                client.send(("open", self.path))
+
+            yield self.Connection(client, self.conn_timeout)
         except Exception as e:
             try:
-                self.workers.put(client)
+                if client.poll(self.conn_timeout):
+                    client.recv()
             except:
                 pass
 
             raise StarryError(f"Caught exception: {e.__doc__}({e})")
-
-        try:
-            yield self.Connection(client)
-        except Exception as e:
-            raise StarryError(f"Caught exception: {e.__doc__}({e})")
         finally:
-            try:
-                self.workers.put(client)
-            except:
-                pass
+            if thread_flag is False:
+                try:
+                    self.workers.put(client)
+                except:
+                    pass
 
     def close(self):
         self.__del__()
